==> stats-collector_2.1.0~rc2.orig.tar.gz: stats-collector-2.1.0~rc2/stats_collector/stats/all_stats/fred/domain_number_changes.py <==
from stats_collector.stats import Statistics
from stats_collector import FRED_DB
from stats_collector.stats.stat_registry import stat_registry
from ..groups import FRED_DAILY_GROUP


@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesRegistrations(Statistics):
    sql = '''
        SELECT 'registration', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
        WHERE
            type = 3
            AND (crdate::date = '%(date)s'::date)
            AND O.name NOT LIKE '%(monitoring_domain)s'
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB

@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesDeletionsNotPaid(Statistics):
    sql = '''
        SELECT 'deleted_not_paid', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
            JOIN object_state S ON (O.id = S.object_id)
        WHERE
            erdate BETWEEN '%(date)s'::timestamp AND %(midnight)s
            AND S.state_id = 17 AND valid_to IS NULL -- deleteCandidate which was not canceled (e.g. unblocking after law suits)
            AND O.type = 3
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB

@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesDeletionsRegistrars(Statistics):
    sql = '''
        SELECT
            'deleted_by_registrars', COUNT(*)
          FROM
            object_registry oreg
            JOIN domain_history dh ON dh.historyid = oreg.crhistoryid
            JOIN zone z ON z.id = dh.zone
            LEFT JOIN object_state os ON os.object_id = oreg.id AND os.state_id = 17
          WHERE
            erdate BETWEEN '%(date)s'::timestamp AND %(midnight)s
            AND oreg.erdate IS NOT NULL
            AND oreg.type = 3
            AND z.fqdn = 'cz'
            AND os.id IS NULL
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB

@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesGotIntoProtection(Statistics):
    sql = '''
        SELECT 'got_into_protection_period', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
            JOIN object_state S ON (
                O.id = S.object_id
                AND S.state_id = 9 and S.valid_from::date = '%(date)s'::date
            )
        WHERE
            crdate < %(midnight)s
            AND (erdate isnull or erdate >= %(midnight)s)
            AND o.type=3
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB

==> stats-collector_2.5.0.orig.tar.gz: stats-collector-2.5.0/stats_collector/stats/all_stats/fred/domain_number_changes.py <==
from stats_collector import FRED_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry

from ..groups import FRED_DAILY_GROUP


@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesRegistrations(Statistics):
    sql = '''
        SELECT 'registration', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
        WHERE
            type = 3
            AND (crdate::date = '%(date)s'::date)
            AND O.name NOT LIKE '%(monitoring_domain)s'
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB


@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesDeletionsNotPaid(Statistics):
    sql = '''
        SELECT 'deleted_not_paid', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
            JOIN object_state S ON (O.id = S.object_id)
        WHERE
            erdate BETWEEN '%(date)s'::timestamp AND %(midnight)s
            -- deleteCandidate which was not canceled (e.g. unblocking after law suits)
            AND S.state_id = 17 AND valid_to IS NULL
            AND O.type = 3
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB


@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesDeletionsRegistrars(Statistics):
    sql = '''
        SELECT
            'deleted_by_registrars', COUNT(*)
          FROM
            object_registry oreg
            JOIN domain_history dh ON dh.historyid = oreg.crhistoryid
            JOIN zone z ON z.id = dh.zone
            LEFT JOIN object_state os ON os.object_id = oreg.id AND os.state_id = 17
          WHERE
            erdate BETWEEN '%(date)s'::timestamp AND %(midnight)s
            AND oreg.erdate IS NOT NULL
            AND oreg.type = 3
            AND z.fqdn = 'cz'
            AND os.id IS NULL
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB


@stat_registry.register(FRED_DAILY_GROUP)
class DomainChangesGotIntoProtection(Statistics):
    sql = '''
        SELECT 'got_into_protection_period', COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.historyid = O.crhistoryid)
            JOIN zone Z ON (D.zone = Z.id)
            JOIN object_state S ON (
                O.id = S.object_id
                AND S.state_id = 9 and S.valid_from::date = '%(date)s'::date
            )
        WHERE
            crdate < %(midnight)s
            AND (erdate isnull or erdate >= %(midnight)s)
            AND o.type=3
            AND Z.fqdn = 'cz'
    '''
    name = 'domain_number_changes'
    stat_db = FRED_DB
